# Copyright © 2021-2022 Arrikto Inc.  All Rights Reserved.

"""Kale SDK.

This script runs a pipeline that calculates the outer product of two lists.
"""

import numpy as np

from kale.sdk import step, pipeline
from random import randint


@step(name="generate-lists")
def list_gen(len_1, len_2):
    """Generate two random lists of given lengths."""
    list_1 = [randint(1, 100) for _ in range(int(len_1))]
    list_2 = [randint(1, 100) for _ in range(int(len_2))]
    return list_1, list_2


@step(name="multiply-lists")
def list_mul(l_1, l_2):
    """Multiply two lists and create two outer-product matrices."""
    return np.outer(l_1, l_2), np.outer(l_2, l_1)


@step(name="print-matrices")
def mat_print(mat_1, mat_2):
    """Print two matrices."""
    print(mat_1, mat_2)


@pipeline(name="typed-pipeline", experiment="kale-tutorial")
def pipeline_func(len_1=42, len_2=17):
    """The pipeline function."""
    l_1, l_2 = list_gen(len_1, len_2)
    mat_1, mat_2 = list_mul(l_1, l_2)
    mat_print(mat_1, mat_2)


if __name__ == "__main__":
    pipeline_func()
